==> uoa-login-core-3.0.0-sources.jar: eu/dnetlib/authentication/security/OpenAIRELogoutSuccessHandler.java <==
package eu.dnetlib.authentication.security;

import eu.dnetlib.authentication.configuration.Properties;
import eu.dnetlib.authentication.services.UserInfoService;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.logout.LogoutSuccessHandler;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;

@Component
public class OpenAIRELogoutSuccessHandler implements LogoutSuccessHandler {

    private final Properties properties;
    private final UserInfoService service;

    @Autowired
    public OpenAIRELogoutSuccessHandler(Properties properties, UserInfoService service) {
        this.properties = properties;
        this.service = service;
    }

    private String encodeValue(String value) {
        return URLEncoder.encode(value, StandardCharsets.UTF_8);
    }

    @Override
    public void onLogoutSuccess(HttpServletRequest request, HttpServletResponse response, Authentication authentication) throws IOException {
        response.sendRedirect(this.service.getClient().getProviderDetails().getConfigurationMetadata().get("end_session_endpoint") +
             "?client_id=" + properties.getKeycloak().getId() +
             "&post_logout_redirect_uri=" + encodeValue(properties.getKeycloak().getRedirect()));
    }
}

==> uoa-login-core-3.0.1-sources.jar: eu/dnetlib/authentication/security/OpenAIRELogoutSuccessHandler.java <==
package eu.dnetlib.authentication.security;

import eu.dnetlib.authentication.configuration.Keycloak;
import eu.dnetlib.authentication.configuration.Properties;
import eu.dnetlib.authentication.services.UserInfoService;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.logout.LogoutSuccessHandler;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;

@Component
public class OpenAIRELogoutSuccessHandler implements LogoutSuccessHandler {

    private final Keycloak keycloak;
    private final UserInfoService service;

    @Autowired
    public OpenAIRELogoutSuccessHandler(Properties properties, UserInfoService service) {
        this.keycloak = properties.getKeycloak();
        this.service = service;
    }

    private String encodeValue(String value) {
        return URLEncoder.encode(value, StandardCharsets.UTF_8);
    }

    @Override
    public void onLogoutSuccess(HttpServletRequest request, HttpServletResponse response, Authentication authentication) throws IOException {
        response.sendRedirect(this.service.getClient().getProviderDetails().getConfigurationMetadata().get("end_session_endpoint") +
             "?client_id=" + keycloak.getId() +
             "&post_logout_redirect_uri=" + encodeValue(keycloak.getRedirect()));
    }
}
